@@ -4,6 +4,7 @@ package # hide from PAUSE
 use strict;
 use warnings;
 use Carp 'croak';
+use Scalar::Util 'blessed';
 use constant PLACEHOLDER => "\x{b1}\x{a4}\x{221e}";
 
 our @CARP_NOT = qw(DBIx::DBO DBIx::DBO::DBD DBIx::DBO::Table DBIx::DBO::Query DBIx::DBO::Row);
@@ -15,6 +16,13 @@ our @CARP_NOT = qw(DBIx::DBO DBIx::DBO::DBD DBIx::DBO::Table DBIx::DBO::Query DB
 our $placeholder = PLACEHOLDER;
 $placeholder = qr/\Q$placeholder/;
 
+sub _isa {
+    my($me, @class) = @_;
+    if (blessed $me) {
+        $me->isa($_) and return 1 for @class;
+    }
+}
+
 sub _init_dbo {
     my($class, $me) = @_;
     return $me;
@@ -197,10 +205,10 @@ sub _bind_params_delete {
 }
 
 sub _build_table {
-    my($class, $me, $t) = @_;
+    my($class, $me, $h, $t) = @_;
     my $alias = $me->_table_alias($t);
     $alias = defined $alias ? ' '.$class->_qi($me, $alias) : '';
-    $t->_quoted_name.$alias;
+    $t->_from.$alias;
 }
 
 sub _build_show {
@@ -211,7 +219,7 @@ sub _build_show {
     return $h->{show} = $distinct.'*' unless @{$h->{Showing}};
     my @flds;
     for my $fld (@{$h->{Showing}}) {
-        push @flds, UNIVERSAL::isa($fld, 'DBIx::DBO::Table')
+        push @flds, _isa($fld, 'DBIx::DBO::Table')
             ? $class->_qi($me, $me->_table_alias($fld) || $fld->{Name}).'.*'
             : $class->_build_val($me, $h->{Show_Bind}, @$fld);
     }
@@ -222,13 +230,14 @@ sub _build_from {
     my($class, $me, $h) = @_;
     return $h->{from} if defined $h->{from};
     undef @{$h->{From_Bind}};
-    $h->{from} = $class->_build_table($me, ($me->tables)[0]);
-    for (my $i = 1; $i < $me->tables; $i++) {
-        $h->{from} .= $h->{Join}[$i].$class->_build_table($me, ($me->tables)[$i]);
-        $h->{from} .= ' ON '.join(' AND ', $class->_build_where_chunk($me, $h->{From_Bind}, 'OR', $h->{Join_On}[$i]))
+    my @tables = $me->tables;
+    my $from = $class->_build_table($me, $h, $tables[0]);
+    for (my $i = 1; $i < @tables; $i++) {
+        $from .= $h->{Join}[$i].$class->_build_table($me, $h, $tables[$i]);
+        $from .= ' ON '.join(' AND ', $class->_build_where_chunk($me, $h->{From_Bind}, 'OR', $h->{Join_On}[$i]))
             if $h->{Join_On}[$i];
     }
-    $h->{from};
+    return $from;
 }
 
 sub _parse_col_val {
@@ -265,11 +274,11 @@ sub _valid_col {
 sub _parse_col {
     my($class, $me, $col, $_check_aliases) = @_;
     if (ref $col) {
-        return $class->_valid_col($me, $col) if UNIVERSAL::isa($col, 'DBIx::DBO::Column');
+        return $class->_valid_col($me, $col) if _isa($col, 'DBIx::DBO::Column');
         croak 'Invalid column: '.$col;
     }
     # If $_check_aliases is not defined dont accept an alias
-    $me->column($col, $_check_aliases || 0);
+    $me->_inner_col($col, $_check_aliases || 0);
 }
 
 sub _build_col {
@@ -303,7 +312,7 @@ sub _parse_val {
         } else {
             $fld = exists $fld->{VAL} ? $fld->{VAL} : [];
         }
-    } elsif (UNIVERSAL::isa($fld, 'DBIx::DBO::Column')) {
+    } elsif (_isa($fld, 'DBIx::DBO::Column')) {
         return [ $class->_valid_col($me, $fld) ];
     }
     $fld = [$fld] unless ref $fld eq 'ARRAY';
@@ -337,7 +346,7 @@ sub _build_val {
         if (!ref $_) {
             push @$bind, $_;
             '?';
-        } elsif (UNIVERSAL::isa($_, 'DBIx::DBO::Column')) {
+        } elsif (_isa($_, 'DBIx::DBO::Column')) {
             $class->_build_col($me, $_);
         } elsif (ref $_ eq 'SCALAR') {
             $$_;
@@ -605,7 +614,7 @@ sub _reset_row_on_update {
             next if $cant_update[ $me->_column_idx($update[0]) ] = (
                 defined $update[1][1] or @{$update[1][0]} != 1 or (
                     ref $update[1][0][0] and (
-                        not UNIVERSAL::isa($update[1][0][0], 'DBIx::DBO::Column')
+                        not _isa($update[1][0][0], 'DBIx::DBO::Column')
                             or $cant_update[ $me->_column_idx($update[1][0][0]) ]
                     )
                 )
