@@ -8,6 +8,8 @@ use overload '**' => \&column, fallback => 1;
 
 sub _row_class { $_[0]{DBO}->_row_class }
 
+*_isa = \&DBIx::DBO::DBD::_isa;
+
 =head1 NAME
 
 DBIx::DBO::Table - An OO interface to SQL queries and results.  Encapsulates a table in an object.
@@ -52,7 +54,7 @@ Tables can be specified by their name or an arrayref of schema and table name or
 
 sub new {
     my $proto = shift;
-    UNIVERSAL::isa($_[0], 'DBIx::DBO') or croak 'Invalid DBO Object';
+    eval { $_[0]->isa('DBIx::DBO') } or croak 'Invalid DBO Object';
     my $class = ref($proto) || $proto;
     $class->_init(@_);
 }
@@ -90,9 +92,9 @@ sub name {
     wantarray ? @{$_[0]}{qw(Schema Name)} : $_[0]->{Name};
 }
 
-sub _quoted_name {
+sub _from {
     my $me = shift;
-    defined $me->{_quoted_name} ? $me->{_quoted_name} : ($me->{_quoted_name} = $me->{DBO}{dbd_class}->_qi($me, @$me{qw(Schema Name)}));
+    defined $me->{_from} ? $me->{_from} : ($me->{_from} = $me->{DBO}{dbd_class}->_qi($me, @$me{qw(Schema Name)}));
 }
 
 =head3 C<columns>
@@ -118,10 +120,11 @@ The C<**> method is a shortcut for the C<column> method.
 sub column {
     my($me, $col) = @_;
     croak 'Missing argument for column' unless defined $col;
-    croak 'Invalid column '.$me->{DBO}{dbd_class}->_qi($me, $col).' in table '.$me->_quoted_name
+    croak 'Invalid column '.$me->{DBO}{dbd_class}->_qi($me, $col).' in table '.$me->_from
         unless exists $me->{Column_Idx}{$col};
     $me->{Column}{$col} ||= bless [$me, $col], 'DBIx::DBO::Column';
 }
+*_inner_col = \&column;
 
 =head3 C<row>
 
@@ -166,7 +169,7 @@ sub fetch_value {
     my($me, $col) = splice @_, 0, 2;
     my @bind;
     $col = $me->{DBO}{dbd_class}->_build_val($me, \@bind, $me->{DBO}{dbd_class}->_parse_col_val($me, $col));
-    my $sql = "SELECT $col FROM ".$me->_quoted_name;
+    my $sql = "SELECT $col FROM ".$me->_from;
     $sql .= ' WHERE '.$_ if $_ = $me->{DBO}{dbd_class}->_build_quick_where($me, \@bind, @_);
     my $ref = $me->{DBO}{dbd_class}->_selectrow_arrayref($me, $sql, undef, @bind);
     return $ref && $ref->[0];
@@ -182,7 +185,7 @@ Fetch the first matching row from the table returning it as a hashref.
 
 sub fetch_hash {
     my $me = shift;
-    my $sql = 'SELECT * FROM '.$me->_quoted_name;
+    my $sql = 'SELECT * FROM '.$me->_from;
     my @bind;
     $sql .= ' WHERE '.$_ if $_ = $me->{DBO}{dbd_class}->_build_quick_where($me, \@bind, @_);
     $me->{DBO}{dbd_class}->_selectrow_hashref($me, $sql, undef, @bind);
@@ -200,7 +203,7 @@ sub fetch_column {
     my($me, $col) = splice @_, 0, 2;
     my @bind;
     $col = $me->{DBO}{dbd_class}->_build_val($me, \@bind, $me->{DBO}{dbd_class}->_parse_col_val($me, $col));
-    my $sql = "SELECT $col FROM ".$me->_quoted_name;
+    my $sql = "SELECT $col FROM ".$me->_from;
     $sql .= ' WHERE '.$_ if $_ = $me->{DBO}{dbd_class}->_build_quick_where($me, \@bind, @_);
     $me->{DBO}{dbd_class}->_sql($me, $sql, @bind);
     return $me->rdbh->selectcol_arrayref($sql, undef, @bind);
@@ -219,7 +222,7 @@ the autogenerated ID (if there was one) from the last inserted row.
 
 sub insert {
     my $me = shift;
-    croak 'Called insert() without args on table '.$me->_quoted_name unless @_;
+    croak 'Called insert() without args on table '.$me->_from unless @_;
     croak 'Wrong number of arguments' if @_ & 1;
     my @cols;
     my @vals;
@@ -232,7 +235,7 @@ sub insert {
         push @cols, $col;
         push @vals, $me->{DBO}{dbd_class}->_build_val($me, \@bind, @val);
     }
-    my $sql = 'INSERT INTO '.$me->_quoted_name.' ('.join(', ', @cols).') VALUES ('.join(', ', @vals).')';
+    my $sql = 'INSERT INTO '.$me->_from.' ('.join(', ', @cols).') VALUES ('.join(', ', @vals).')';
     $me->{DBO}{dbd_class}->_sql($me, $sql, @bind);
     my $sth = $me->dbh->prepare($sql) or return undef;
     my $rv = $sth->execute(@bind) or return undef;
@@ -280,7 +283,7 @@ the autogenerated ID (if there was one) from the last inserted row.
 sub bulk_insert {
     my($me, %opt) = @_;
     croak 'The "rows" argument must be an arrayref' if ref $opt{rows} ne 'ARRAY';
-    my $sql = 'INSERT INTO '.$me->_quoted_name;
+    my $sql = 'INSERT INTO '.$me->_from;
 
     my @cols;
     if (defined $opt{columns}) {
@@ -305,7 +308,7 @@ Delete all rows from the table matching the criteria.  Returns the number of row
 
 sub delete {
     my $me = shift;
-    my $sql = 'DELETE FROM '.$me->_quoted_name;
+    my $sql = 'DELETE FROM '.$me->_from;
     my @bind;
     $sql .= ' WHERE '.$_ if $_ = $me->{DBO}{dbd_class}->_build_quick_where($me, \@bind, @_);
     $me->{DBO}{dbd_class}->_do($me, $sql, undef, @bind);
@@ -321,7 +324,7 @@ Truncate the table.  Returns true on success or C<undef> on failure.
 
 sub truncate {
     my $me = shift;
-    $me->{DBO}{dbd_class}->_do($me, 'TRUNCATE TABLE '.$me->_quoted_name);
+    $me->{DBO}{dbd_class}->_do($me, 'TRUNCATE TABLE '.$me->_from);
 }
 
 =head2 Common Methods
